@@ -236,15 +236,16 @@ class Postgres_Handler:
         table_name_key = "table_name"
         id_key = "ID"
         
-        value_dict = {key: value for key, value in keywords.items() if key.lower() == table_name_key.lower() or key.lower() == id_key.lower()}
+        value_dict = {key: value for key, value in keywords.items() if key.lower() == id_key.lower()}
         
         #Builds query to run 
         query_string = 'DELETE FROM {table_name} WHERE ID = {Id}'
         sql_query = sql.SQL(query_string).format(
             table_name = sql.Identifier(keywords[table_name_key]),
-            Id= sql.Identifier(keywords[id_key])
+            Id= sql.Placeholder(id_key)
         )
         
         #Runs the query and handles the success or error.
         results = self.__run_query(sql_query, value_dict)
-        return results
+        
+        return self.__format_results(results)
